import { ViewContainerLocation, ViewContainer, IViewContainersRegistry, IViewsRegistry } from 'vscode/vscode/vs/workbench/common/views';
export { IViewContainerDescriptor, IViewDescriptor, ViewContainer, ViewContainerLocation } from 'vscode/vscode/vs/workbench/common/views';
import { BrandedService, ServicesAccessor } from 'vscode/vscode/vs/platform/instantiation/common/instantiation';
import { IDisposable } from 'vscode/vscode/vs/base/common/lifecycle';
import { Dimension } from 'vscode/vscode/vs/base/browser/dom';
import { Event } from 'vscode/vscode/vs/base/common/event';
import { DomScrollableElement } from 'vscode/vscode/vs/base/browser/ui/scrollbar/scrollableElement';
export { DomScrollableElement } from 'vscode/vscode/vs/base/browser/ui/scrollbar/scrollableElement';
import { CancellationToken } from 'vscode/vscode/vs/base/common/cancellation';
import { URI } from 'vscode/vscode/vs/base/common/uri';
import { IEditorOptions } from 'vscode/vscode/vs/platform/editor/common/editor';
import { Parts, Position } from 'vscode/vscode/vs/workbench/services/layout/browser/layoutService';
export { Parts } from 'vscode/vscode/vs/workbench/services/layout/browser/layoutService';
import { Codicon } from 'vscode/vscode/vs/base/common/codicons';
import { RegisteredEditorInfo, RegisteredEditorOptions, EditorInputFactoryObject } from 'vscode/vscode/vs/workbench/services/editor/common/editorResolverService';
export { EditorInputFactoryObject, RegisteredEditorInfo, RegisteredEditorOptions, RegisteredEditorPriority } from 'vscode/vscode/vs/workbench/services/editor/common/editorResolverService';
import { EditorInput, IEditorCloseHandler } from 'vscode/vscode/vs/workbench/common/editor/editorInput';
export { EditorInput, IEditorCloseHandler } from 'vscode/vscode/vs/workbench/common/editor/editorInput';
import { IEditorOpenContext, EditorInputCapabilities, Verbosity, IEditorSerializer } from 'vscode/vscode/vs/workbench/common/editor';
export { EditorInputCapabilities, IEditorSerializer } from 'vscode/vscode/vs/workbench/common/editor';
import { EditorPane } from 'vscode/vscode/vs/workbench/browser/parts/editor/editorPane';
import { IEditorGroup } from 'vscode/vscode/vs/workbench/services/editor/common/editorGroupsService';

type Label = string | {
    short: string;
    medium: string;
    long: string;
};
declare abstract class InjectedEditorPane extends EditorPane {
    constructor(id: string);
}
declare abstract class SimpleEditorPane extends InjectedEditorPane {
    protected container: HTMLElement;
    protected wrapper: HTMLElement;
    protected scrollbar: DomScrollableElement | undefined;
    private inputDisposable;
    protected createEditor(parent: HTMLElement): void;
    setInput(input: EditorInput, editorOptions: IEditorOptions | undefined, context: IEditorOpenContext, token: CancellationToken): Promise<void>;
    layout(dimension: Dimension): void;
    focus(): void;
    clearInput(): void;
    abstract initialize(): HTMLElement;
    abstract renderInput?(input: EditorInput, options: IEditorOptions | undefined, context: IEditorOpenContext, token: CancellationToken): Promise<IDisposable>;
}
declare abstract class SimpleEditorInput extends EditorInput {
    closeHandler?: IEditorCloseHandler | undefined;
    private dirty;
    private _capabilities;
    private name;
    private title;
    private description;
    resource: URI | undefined;
    constructor(resource?: URI, closeHandler?: IEditorCloseHandler | undefined);
    get capabilities(): EditorInputCapabilities;
    addCapability(capability: EditorInputCapabilities): void;
    removeCapability(capability: EditorInputCapabilities): void;
    get editorId(): string | undefined;
    setName(name: string): void;
    setTitle(title: Label): void;
    setDescription(description: string): void;
    private getLabelValue;
    getName(): string;
    getTitle(verbosity?: Verbosity): string;
    getDescription(verbosity?: Verbosity): string;
    isDirty(): boolean;
    setDirty(dirty: boolean): void;
}
declare function registerEditorPane<Services extends BrandedService[]>(typeId: string, name: string, ctor: new (group: IEditorGroup, ...services: Services) => EditorPane, inputCtors: (new (...args: any[]) => EditorInput)[]): IDisposable;
declare function registerEditor(globPattern: string, editorInfo: RegisteredEditorInfo, editorOptions: RegisteredEditorOptions, factory: EditorInputFactoryObject): IDisposable;
declare function registerEditorSerializer<Services extends BrandedService[]>(editorTypeId: string, ctor: {
    new (...Services: Services): IEditorSerializer;
}): IDisposable;
interface CustomViewOption {
    readonly id: string;
    name: string;
    order?: number;
    renderBody(container: HTMLElement, scrollbar: DomScrollableElement): IDisposable;
    location: ViewContainerLocation;
    icon?: string;
    canMoveView?: boolean;
    default?: boolean;
    actions?: {
        id: string;
        title: string;
        tooltip?: string;
        order?: number;
        run?(accessor: ServicesAccessor): Promise<void>;
        icon?: keyof typeof Codicon;
        render?(container: HTMLElement): void;
    }[];
    viewContainer?: ViewContainer;
    canToggleVisibility?: boolean;
    hideByDefault?: boolean;
    collapsed?: boolean;
}
declare const viewContainerRegistry: IViewContainersRegistry;
declare const viewRegistry: IViewsRegistry;
declare function registerCustomView(options: CustomViewOption): IDisposable;
declare function isPartVisibile(part: Parts): boolean;
declare function setPartVisibility(part: Exclude<Parts, Parts.STATUSBAR_PART | Parts.TITLEBAR_PART>, visible: boolean): void;
declare const onDidChangePanelPosition: Event<string>;
declare function getPanelPosition(): Position;
declare const onDidChangeSideBarPosition: Event<string>;
declare function getSideBarPosition(): Position;

export { type CustomViewOption, InjectedEditorPane as EditorPane, SimpleEditorInput, SimpleEditorPane, getPanelPosition, getSideBarPosition, isPartVisibile, onDidChangePanelPosition, onDidChangeSideBarPosition, registerCustomView, registerEditor, registerEditorPane, registerEditorSerializer, setPartVisibility, viewContainerRegistry, viewRegistry };
